@@ -8,7 +8,7 @@ expected_exception = 0;
 ## check module load
 disp("checking module load ...");
 lal;
-assert(exist("lal", "var"));
+assert(exist("lal"));
 lal_c_si = LAL_C_SI;
 lal_180_pi = LAL_180_PI;
 disp("PASSED module load");
@@ -275,6 +275,9 @@ assert(all(swig_lal_test_copyin_array1(a1in, 2.5) == a1out));
 a2in = int32([3,2; 7,6; 12,10]);
 a2out = a2in * 15;
 assert(all(swig_lal_test_copyin_array2(a2in, 15) == a2out));
+a3in = {lal.LIGOTimeGPS(1234.5); lal.LIGOTimeGPS(678.9)};
+a3out = {a3in{1} * 3; a3in{2} * 3};
+assert(all(cellfun(@(x, y) x == y, lal.swig_lal_test_copyin_array3(a3in, 3), a3out)));
 try
   swig_lal_test_viewin_array1([0,0,0,0], 0);
   expected_exception = 1;
@@ -285,10 +288,43 @@ try
   expected_exception = 1;
 end_try_catch
 assert(!expected_exception);
+clear a3in;
+clear a3out;
+LALCheckMemoryLeaks();
 disp("PASSED fixed and dynamic arrays typemaps")
 
-## check input views of array structs
-disp("checking input views of array structs ...");
+## check input views of string array structs
+disp("checking input views of string array structs ...");
+svdat = {"a"; "bc"; "def"};
+sv = XLALCreateEmptyStringVector(length(svdat));
+sv.data = svdat;
+svout = XLALCreateEmptyStringVector(length(svdat));
+[svout.data{1:length(svdat)}] = deal("");
+assert(swig_lal_test_viewin_LALStringVector(svout, sv));
+assert(all(cellfun(@(x, y) strcmp(x, y), svout.data, sv.data)));
+[svout.data{1:length(svdat)}] = deal("");
+assert(swig_lal_test_viewin_LALStringVector(svout, svdat));
+assert(all(cellfun(@(x, y) strcmp(x, y), svout.data, svdat)));
+sv.data = svdat;
+assert(swig_lal_test_copyinout_LALStringVector(sv));
+assert(all(cellfun(@(x, y) strcmp(x, toupper(y)), sv.data, svdat)));
+sv.data = svdat;
+[retn, sv] = swig_lal_test_copyinout_LALStringVector(sv);
+assert(retn);
+assert(all(cellfun(@(x, y) strcmp(x, toupper(y)), sv.data, svdat)));
+sv = svdat;
+[retn, sv] = swig_lal_test_copyinout_LALStringVector(sv);
+assert(retn);
+assert(all(cellfun(@(x, y) strcmp(x, toupper(y)), sv, svdat)));
+clear sv;
+clear svout;
+clear svdat;
+clear ans;
+LALCheckMemoryLeaks();
+disp("PASSED input views of string array structs");
+
+## check input views of numeric array structs
+disp("checking input views of numeric array structs ...");
 r4dat = single([1.2; 2.3; 3.4; 4.5; 5.6]);
 r8dat = double([3.4; 4.5; 5.6; 6.7; 7.8; 8.9]);
 c8dat = complex(r4dat, 8 + r4dat);
@@ -521,7 +557,7 @@ clear c16out;
 clear c16dat;
 clear ans;
 LALCheckMemoryLeaks();
-disp("PASSED input views of array structs (LAL)");
+disp("PASSED input views of numeric array structs (LAL)");
 vfdat = single([1.2; 2.3; 3.4; 4.5; 5.6]);
 vddat = double([3.4; 4.5; 5.6; 6.7; 7.8; 8.9]);
 vcfdat = complex(vfdat, 8 + vfdat);
@@ -754,7 +790,7 @@ clear mcdout;
 clear mcddat;
 clear ans;
 LALCheckMemoryLeaks();
-disp("PASSED input views of array structs (GSL)");
+disp("PASSED input views of numeric array structs (GSL)");
 function check_input_view_type_safety(f, a, b, expect_exception)
   expected_exception = 0;
   if expect_exception
@@ -815,7 +851,7 @@ clear c8;
 clear c16;
 clear ans;
 LALCheckMemoryLeaks();
-disp("PASSED input views of array structs (type safety)");
+disp("PASSED input views of numeric array structs (type safety)");
 
 ## check FFT functions with input views
 disp("check FFT functions with input views ...");
@@ -1055,6 +1091,11 @@ end_try_catch
 assert(!expected_exception);
 disp("*** above should be error messages from LIGOTimeGPS constructor ***");
 assert(swig_lal_test_noptrgps(LIGOTimeGPS(1234.5)) == swig_lal_test_noptrgps(1234.5))
+try
+  LIGOTimeGPS([]);
+  expected_exception = 1;
+end_try_catch
+assert(!expected_exception);
 clear t0;
 clear t1;
 clear t2;
@@ -1108,3 +1149,6 @@ disp("PASSED LALUnit operations");
 
 ## passed all tests!
 disp("PASSED all tests");
+if exist("swig_exit")
+   swig_exit;
+endif
