@@ -83,14 +83,14 @@
  */
 
 /** \name Error Codes */
-/*@{*/
+/** @{ */
 #define DETINVERSETESTC_ENORM 0		/**< Normal exit */
 #define DETINVERSETESTC_ESUB  1		/**< Subroutine failed */
 #define DETINVERSETESTC_EARG  2		/**< Error parsing arguments */
 #define DETINVERSETESTC_EMEM  3		/**< Out of memory */
 #define DETINVERSETESTC_EFILE 4		/**< Could not open file */
 #define DETINVERSETESTC_EFMT  5		/**< Bad input file format */
-/*@}*/
+/** @} */
 
 
 
@@ -339,18 +339,16 @@ main( int argc, char **argv )
 
   /* Generate random matrix. */
   else {
-    RandomParams *params = NULL;
-    SUB( LALCreateRandomParams( &stat, &params, 0 ), &stat );
+    RandomParams *params;
+    params = XLALCreateRandomParams( 0 );
     dimLength.data[0] = dimLength.data[1] = n;
 
     /* Single-precision mode: */
     if ( single ) {
       SUB( LALSCreateArray( &stat, &sMatrix, &dimLength ), &stat );
       for ( i = 0; i < n; i++ ) {
-	REAL4 x;
 	for ( j = 0; j < n; j++ ) {
-	  SUB( LALUniformDeviate( &stat, &x, params ), &stat );
-	  sMatrix->data[i*n+j] = 2.0*x - 1.0;
+	  sMatrix->data[i*n+j] = 2.0*XLALUniformDeviate( params ) - 1.0;
 	}
       }
     }
@@ -359,15 +357,13 @@ main( int argc, char **argv )
     else {
       SUB( LALDCreateArray( &stat, &dMatrix, &dimLength ), &stat );
       for ( i = 0; i < n; i++ ) {
-	REAL4 x;
 	for ( j = 0; j < n; j++ ) {
-	  SUB( LALUniformDeviate( &stat, &x, params ), &stat );
-	  dMatrix->data[i*n+j] = 2.0*(REAL8)( x ) - 1.0;
+	  dMatrix->data[i*n+j] = 2.0*(REAL8)( XLALUniformDeviate( params ) ) - 1.0;
 	}
       }
     }
 
-    SUB( LALDestroyRandomParams( &stat, &params ), &stat );
+    XLALDestroyRandomParams( params );
   }
 
   /* Write input matrix to output file. */
